Crate logfather

source ·

Macros

  • Logs a critical message.
  • Logs a message for debugging.
  • Logs an error message.
  • Logs an informational message.
  • Logs a warning message.

Structs

  • Logger is a struct that encapsulates the configuration for the logging system.

Enums

  • Represents the severity level of a log message.

Functions

  • Logs a message with the specified log level and module path.